@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *
@@ -44,7 +44,12 @@ CalamaresApplication::CalamaresApplication( int& argc, char* argv[] )
     , m_moduleManager( nullptr )
     , m_debugMode( false )
 {
-    setOrganizationName( QLatin1String( CALAMARES_ORGANIZATION_NAME ) );
+    // Setting the organization name makes the default cache
+    // directory -- where Calamares stores logs, for instance --
+    // <org>/<app>/, so we end up with ~/.cache/Calamares/calamares/
+    // which is excessively squidly.
+    //
+    // setOrganizationName( QLatin1String( CALAMARES_ORGANIZATION_NAME ) );
     setOrganizationDomain( QLatin1String( CALAMARES_ORGANIZATION_DOMAIN ) );
     setApplicationName( QLatin1String( CALAMARES_APPLICATION_NAME ) );
     setApplicationVersion( QLatin1String( CALAMARES_VERSION ) );
@@ -65,9 +70,6 @@ CalamaresApplication::CalamaresApplication( int& argc, char* argv[] )
 void
 CalamaresApplication::init()
 {
-    cDebug() << "CalamaresApplication thread:" << thread();
-
-    //TODO: Icon loader
     Logger::setupLogfile();
 
     setQuitOnLastWindowClosed( false );
@@ -89,7 +91,7 @@ CalamaresApplication::init()
 
 CalamaresApplication::~CalamaresApplication()
 {
-    cDebug( LOGVERBOSE ) << "Shutting down Calamares...";
+    cDebug( Logger::LOGVERBOSE ) << "Shutting down Calamares...";
 
 //    if ( JobQueue::instance() )
 //        JobQueue::instance()->stop();
@@ -98,7 +100,7 @@ CalamaresApplication::~CalamaresApplication()
 
 //    delete JobQueue::instance();
 
-    cDebug( LOGVERBOSE ) << "Finished shutdown.";
+    cDebug( Logger::LOGVERBOSE ) << "Finished shutdown.";
 }
 
 
@@ -143,7 +145,7 @@ CalamaresApplication::initQmlPath()
                            .absoluteFilePath( subpath ) );
         if ( !importPath.exists() || !importPath.isReadable() )
         {
-            cLog() << "FATAL ERROR: explicitly configured application data directory"
+            cError() << "FATAL: explicitly configured application data directory"
                    << CalamaresUtils::appDataDir().absolutePath()
                    << "does not contain a valid QML modules directory at"
                    << importPath.absolutePath()
@@ -176,7 +178,7 @@ CalamaresApplication::initQmlPath()
 
         if ( !importPath.exists() || !importPath.isReadable() )
         {
-            cLog() << "FATAL ERROR: none of the expected QML paths ("
+            cError() << "FATAL: none of the expected QML paths ("
                    << qmlDirCandidatesByPriority.join( ", " )
                    << ") exist."
                    << "\nCowardly refusing to continue startup without the QML directory.";
@@ -197,7 +199,7 @@ CalamaresApplication::initSettings()
         settingsFile = QFileInfo( CalamaresUtils::appDataDir().absoluteFilePath( "settings.conf" ) );
         if ( !settingsFile.exists() || !settingsFile.isReadable() )
         {
-            cLog() << "FATAL ERROR: explicitly configured application data directory"
+            cError() << "FATAL: explicitly configured application data directory"
                    << CalamaresUtils::appDataDir().absolutePath()
                    << "does not contain a valid settings.conf file."
                    << "\nCowardly refusing to continue startup without settings.";
@@ -230,7 +232,7 @@ CalamaresApplication::initSettings()
 
         if ( !settingsFile.exists() || !settingsFile.isReadable() )
         {
-            cLog() << "FATAL ERROR: none of the expected configuration file paths ("
+            cError() << "FATAL: none of the expected configuration file paths ("
                    << settingsFileCandidatesByPriority.join( ", " )
                    << ") contain a valid settings.conf file."
                    << "\nCowardly refusing to continue startup without settings.";
@@ -248,7 +250,7 @@ CalamaresApplication::initBranding()
     QString brandingComponentName = Calamares::Settings::instance()->brandingComponentName();
     if ( brandingComponentName.simplified().isEmpty() )
     {
-        cLog() << "FATAL ERROR: branding component not set in settings.conf";
+        cError() << "FATAL: branding component not set in settings.conf";
         ::exit( EXIT_FAILURE );
     }
 
@@ -262,7 +264,7 @@ CalamaresApplication::initBranding()
                                   .absoluteFilePath( brandingDescriptorSubpath ) );
         if ( !brandingFile.exists() || !brandingFile.isReadable() )
         {
-            cLog() << "FATAL ERROR: explicitly configured application data directory"
+            cError() << "FATAL: explicitly configured application data directory"
                    << CalamaresUtils::appDataDir().absolutePath()
                    << "does not contain a valid branding component descriptor at"
                    << brandingFile.absoluteFilePath()
@@ -299,7 +301,7 @@ CalamaresApplication::initBranding()
 
         if ( !brandingFile.exists() || !brandingFile.isReadable() )
         {
-            cLog() << "FATAL ERROR: none of the expected branding descriptor file paths ("
+            cError() << "FATAL: none of the expected branding descriptor file paths ("
                    << brandingFileCandidatesByPriority.join( ", " )
                    << ") contain a valid branding.desc file."
                    << "\nCowardly refusing to continue startup without branding.";
@@ -349,7 +351,7 @@ CalamaresApplication::initViewSteps()
 {
     cDebug() << "STARTUP: loadModules for all modules done";
     m_mainwindow->show();
-    ProgressTreeModel* m = new ProgressTreeModel( this );
+    ProgressTreeModel* m = new ProgressTreeModel( nullptr );
     ProgressTreeView::instance()->setModel( m );
     cDebug() << "STARTUP: Window now visible and ProgressTreeView populated";
 }
