@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *
@@ -41,12 +41,9 @@ public:
         , m_queue( queue )
         , m_jobIndex( 0 )
     {
-#ifdef WITH_PYTHON
-        new CalamaresPython::Helper( this );
-#endif
     }
 
-    void setJobs( const QList< job_ptr >& jobs )
+    void setJobs( const JobList& jobs )
     {
         m_jobs = jobs;
     }
@@ -57,7 +54,7 @@ public:
         for( auto job : m_jobs )
         {
             emitProgress();
-            cLog() << "Starting job" << job->prettyName();
+            cDebug() << "Starting job" << job->prettyName();
             connect( job.data(), &Job::progress, this, &JobThread::emitProgress );
             JobResult result = job->exec();
             if ( !result )
@@ -73,7 +70,7 @@ public:
     }
 
 private:
-    QList< job_ptr > m_jobs;
+    JobList m_jobs;
     JobQueue* m_queue;
     int m_jobIndex;
 
@@ -164,7 +161,7 @@ JobQueue::enqueue( const job_ptr& job )
 
 
 void
-JobQueue::enqueue( const QList< job_ptr >& jobs )
+JobQueue::enqueue( const JobList& jobs )
 {
     Q_ASSERT( !m_thread->isRunning() );
     m_jobs.append( jobs );
