@@ -1,6 +1,7 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2017, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -222,7 +223,7 @@ Helper::Helper( QObject* parent )
     }
     else
     {
-        cDebug() << "WARNING: creating PythonHelper more than once. This is very bad.";
+        cWarning() << "creating PythonHelper more than once. This is very bad.";
         return;
     }
 
@@ -230,7 +231,9 @@ Helper::Helper( QObject* parent )
 }
 
 Helper::~Helper()
-{}
+{
+    s_instance = nullptr;
+}
 
 
 boost::python::dict
@@ -248,8 +251,11 @@ Helper::createCleanNamespace()
 QString
 Helper::handleLastError()
 {
-    PyObject* type = nullptr, *val = nullptr, *tb = nullptr;
-    PyErr_Fetch( &type, &val, &tb );
+    PyObject* type = nullptr, *val = nullptr, *traceback_p = nullptr;
+    PyErr_Fetch( &type, &val, &traceback_p );
+
+    Logger::CDebug debug;
+    debug.noquote() << "Python Error:\n";
 
     QString typeMsg;
     if ( type != nullptr )
@@ -258,10 +264,11 @@ Helper::handleLastError()
         bp::str pystr( h_type );
         bp::extract< std::string > extracted( pystr );
         if ( extracted.check() )
-            typeMsg = QString::fromStdString( extracted() ).toHtmlEscaped();
+            typeMsg = QString::fromStdString( extracted() ).trimmed();
 
-        if ( typeMsg.trimmed().isEmpty() )
+        if ( typeMsg.isEmpty() )
             typeMsg = tr( "Unknown exception type" );
+        debug << typeMsg << '\n';
     }
 
     QString valMsg;
@@ -271,26 +278,51 @@ Helper::handleLastError()
         bp::str pystr( h_val );
         bp::extract< std::string > extracted( pystr );
         if ( extracted.check() )
-            valMsg = QString::fromStdString( extracted() ).toHtmlEscaped();
+            valMsg = QString::fromStdString( extracted() ).trimmed();
 
-        if ( valMsg.trimmed().isEmpty() )
+        if ( valMsg.isEmpty() )
             valMsg = tr( "unparseable Python error" );
+
+        // Special-case: CalledProcessError has an attribute "output" with the command output,
+        // add that to the printed message.
+        if ( typeMsg.contains( "CalledProcessError" ) )
+        {
+            bp::object exceptionObject( h_val );
+            auto a = exceptionObject.attr( "output" );
+            bp::str outputString( a );
+            bp::extract< std::string > extractedOutput( outputString );
+
+            QString output;
+            if ( extractedOutput.check() )
+            {
+                output = QString::fromStdString( extractedOutput() ).trimmed();
+            }
+            if ( !output.isEmpty() )
+            {
+                // Replace the Type of the error by the warning string,
+                // and use the output of the command (e.g. its stderr) as value.
+                typeMsg = valMsg;
+                valMsg = output;
+            }
+        }
+        debug << valMsg << '\n';
     }
 
     QString tbMsg;
-    if ( tb != nullptr )
+    if ( traceback_p != nullptr )
     {
-        bp::handle<> h_tb( tb );
-        bp::object tb( bp::import( "traceback" ) );
-        bp::object format_tb( tb.attr( "format_tb" ) );
+        bp::handle<> h_tb( traceback_p );
+        bp::object traceback_module( bp::import( "traceback" ) );
+        bp::object format_tb( traceback_module.attr( "format_tb" ) );
         bp::object tb_list( format_tb( h_tb ) );
         bp::object pystr( bp::str( "\n" ).join( tb_list ) );
         bp::extract< std::string > extracted( pystr );
         if ( extracted.check() )
-            tbMsg = QString::fromStdString( extracted() ).toHtmlEscaped();
+            tbMsg = QString::fromStdString( extracted() ).trimmed();
 
-        if ( tbMsg.trimmed().isEmpty() )
+        if ( tbMsg.isEmpty() )
             tbMsg = tr( "unparseable Python traceback" );
+        debug << tbMsg << '\n';
     }
 
     if ( typeMsg.isEmpty() && valMsg.isEmpty() && tbMsg.isEmpty() )
@@ -298,18 +330,15 @@ Helper::handleLastError()
 
 
     QStringList msgList;
-
     if ( !typeMsg.isEmpty() )
-        msgList.append( QString( "<strong>%1</strong>" ).arg( typeMsg ) );
-
+        msgList.append( QString( "<strong>%1</strong>" ).arg( typeMsg.toHtmlEscaped() ) );
     if ( !valMsg.isEmpty() )
-        msgList.append( valMsg );
+        msgList.append( valMsg.toHtmlEscaped() );
 
     if ( !tbMsg.isEmpty() )
     {
-        msgList.append( "Traceback:" );
-        msgList.append( QString( "<pre>%1</pre>" ).arg( tbMsg ) );
-        cDebug() << "tbMsg" << tbMsg;
+        msgList.append( QStringLiteral( "<br/>Traceback:" ) );
+        msgList.append( QString( "<pre>%1</pre>" ).arg( tbMsg.toHtmlEscaped() ) );
     }
 
     // Return a string made of the msgList items, wrapped in <div> tags
