@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
  *
@@ -99,6 +99,13 @@ BOOST_PYTHON_MODULE( libcalamares )
         bp::args( "s" ),
         "Writes the given string to the Calamares debug stream."
     );
+    bp::def(
+        "warning",
+        &CalamaresPython::warning,
+        bp::args( "s" ),
+        "Writes the given string to the Calamares warning stream."
+    );
+
     bp::def(
         "mount",
         &CalamaresPython::mount,
@@ -322,7 +329,7 @@ PythonJob::exec()
             }
             if ( !m_description.isEmpty() )
             {
-                cDebug() << "Job" << prettyName() << "(func) ->" << m_description;
+                cDebug() << "Job description from pretty_name" << prettyName() << "=" << m_description;
                 emit progress( 0 );
             }
         }
@@ -337,7 +344,7 @@ PythonJob::exec()
                 auto i_newline = m_description.indexOf('\n');
                 if ( i_newline > 0 )
                     m_description.truncate( i_newline );
-                cDebug() << "Job" << prettyName() << "(doc) ->" << m_description;
+                cDebug() << "Job description from __doc__" << prettyName() << "=" << m_description;
                 emit progress( 0 );
             }
         }
@@ -381,8 +388,10 @@ PythonJob::emitProgress( qreal progressValue )
 CalamaresPython::Helper*
 PythonJob::helper()
 {
-    return CalamaresPython::Helper::s_instance;
-
+    auto ptr = CalamaresPython::Helper::s_instance;
+    if (!ptr)
+        ptr = new CalamaresPython::Helper;
+    return ptr;
 }
 
 
