@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
@@ -100,6 +100,7 @@ ViewManager::ViewManager( QObject* parent )
 ViewManager::~ViewManager()
 {
     m_widget->deleteLater();
+    s_instance = nullptr;
 }
 
 
@@ -149,9 +150,9 @@ ViewManager::insertViewStep( int before, ViewStep* step )
 void
 ViewManager::onInstallationFailed( const QString& message, const QString& details )
 {
-    cLog() << "Installation failed:";
-    cLog() << "- message:" << message;
-    cLog() << "- details:" << details;
+    cError() << "Installation failed:";
+    cDebug() << "- message:" << message;
+    cDebug() << "- details:" << details;
 
     QMessageBox* msgBox = new QMessageBox();
     msgBox->setIcon( QMessageBox::Critical );
@@ -166,7 +167,7 @@ ViewManager::onInstallationFailed( const QString& message, const QString& detail
     msgBox->setInformativeText( text );
 
     connect( msgBox, &QMessageBox::buttonClicked, qApp, &QApplication::quit );
-    cLog() << "Calamares will quit when the dialog closes.";
+    cDebug() << "Calamares will quit when the dialog closes.";
     msgBox->show();
 }
 
@@ -191,6 +192,11 @@ ViewManager::currentStepIndex() const
     return m_currentStep;
 }
 
+static inline bool
+stepNextWillExecute(const ViewStepList& steps, int index)
+{
+    return ( index + 1 < steps.count() ) && qobject_cast< ExecutionViewStep* >( steps.at( index + 1 ) );
+}
 
 void
 ViewManager::next()
@@ -202,9 +208,7 @@ ViewManager::next()
         // Special case when the user clicks next on the very last page in a view phase
         // and right before switching to an execution phase.
         // Depending on Calamares::Settings, we show an "are you sure" prompt or not.
-        if ( Calamares::Settings::instance()->showPromptBeforeExecution() &&
-                m_currentStep + 1 < m_steps.count() &&
-                qobject_cast< ExecutionViewStep* >( m_steps.at( m_currentStep + 1 ) ) )
+        if ( Calamares::Settings::instance()->showPromptBeforeExecution() && stepNextWillExecute( m_steps, m_currentStep ) )
         {
             int reply =
                 QMessageBox::question( m_widget,
@@ -241,15 +245,29 @@ ViewManager::next()
     m_next->setEnabled( !executing && m_steps.at( m_currentStep )->isNextEnabled() );
     m_back->setEnabled( !executing && m_steps.at( m_currentStep )->isBackEnabled() );
 
-    if ( m_currentStep == m_steps.count() -1 &&
-            m_steps.last()->isAtEnd() )
+    updateButtonLabels();
+}
+
+void
+ViewManager::updateButtonLabels()
+{
+    if ( stepNextWillExecute( m_steps, m_currentStep ) )
+        m_next->setText( tr( "&Install" ) );
+    else
+        m_next->setText( tr( "&Next" ) );
+
+    if ( m_currentStep == m_steps.count() -1 && m_steps.last()->isAtEnd() )
     {
         m_quit->setText( tr( "&Done" ) );
         m_quit->setToolTip( tr( "The installation is complete. Close the installer." ) );
     }
+    else
+    {
+        m_quit->setText( tr( "&Cancel" ) );
+        m_quit->setToolTip( tr( "Cancel installation without changing the system." ) );
+    }
 }
 
-
 void
 ViewManager::back()
 {
@@ -272,12 +290,7 @@ ViewManager::back()
     if ( m_currentStep == 0 && m_steps.first()->isAtBeginning() )
         m_back->setEnabled( false );
 
-    if ( !( m_currentStep == m_steps.count() -1 &&
-            m_steps.last()->isAtEnd() ) )
-    {
-        m_quit->setText( tr( "&Cancel" ) );
-        m_quit->setToolTip( tr( "Cancel installation without changing the system." ) );
-    }
+    updateButtonLabels();
 }
 
 bool ViewManager::confirmCancelInstallation()
