@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017, Adriaan de Groot <groot@kde.org>
@@ -129,7 +129,7 @@ QPoint TimeZoneWidget::getLocationPosition( double longitude, double latitude )
     if ( y >= height )
         y -= height;
 
-    return QPoint( ( int )x, ( int )y );
+    return QPoint( int(x), int(y) );
 }
 
 
