@@ -3,6 +3,7 @@
  *   Copyright 2016, Lisa Vitolo     <shainer@chakraos.org>
  *   Copyright 2017, Kyle Robbertze  <krobbertze@gmail.com>
  *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017, Gabriel Craciunescu <crazy@frugalware.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -56,14 +57,6 @@ NetInstallPage::NetInstallPage( QWidget* parent )
     ui->setupUi( this );
 }
 
-bool
-NetInstallPage::isReady()
-{
-    // nothing to wait for, the data are immediately ready
-    // if the user does not select any group nothing is installed
-    return true;
-}
-
 bool
 NetInstallPage::readGroups( const QByteArray& yamlData )
 {
@@ -72,12 +65,12 @@ NetInstallPage::readGroups( const QByteArray& yamlData )
         YAML::Node groups = YAML::Load( yamlData.constData() );
 
         if ( !groups.IsSequence() )
-            cDebug() << "WARNING: netinstall groups data does not form a sequence.";
+            cWarning() << "netinstall groups data does not form a sequence.";
         Q_ASSERT( groups.IsSequence() );
         m_groups = new PackageModel( groups );
         CALAMARES_RETRANSLATE(
             m_groups->setHeaderData( 0, Qt::Horizontal, tr( "Name" ) );
-            m_groups->setHeaderData( 0, Qt::Horizontal, tr( "Description" ) ); )
+            m_groups->setHeaderData( 1, Qt::Horizontal, tr( "Description" ) ); )
         return true;
 
     }
@@ -91,18 +84,26 @@ NetInstallPage::readGroups( const QByteArray& yamlData )
 void
 NetInstallPage::dataIsHere( QNetworkReply* reply )
 {
+    // If m_required is *false* then we still say we're ready
+    // even if the reply is corrupt or missing.
     if ( reply->error() != QNetworkReply::NoError )
     {
-        cDebug() << reply->errorString();
+        cWarning() << "unable to fetch netinstall package lists.";
+        cDebug() << "  ..Netinstall reply error: " << reply->error();
+        cDebug() << "  ..Request for url: " << reply->url().toString() << " failed with: " << reply->errorString();
         ui->netinst_status->setText( tr( "Network Installation. (Disabled: Unable to fetch package lists, check your network connection)" ) );
+        emit checkReady( !m_required );
         return;
     }
 
     if ( !readGroups( reply->readAll() ) )
     {
-        cDebug() << "Netinstall groups data was received, but invalid.";
-        ui->netinst_status->setText( tr( "Network Installation. (Disabled: Unable to fetch package lists, check your network connection)" ) );
+        cWarning() << "netinstall groups data was received, but invalid.";
+        cDebug() << "  ..Url:     " <<  reply->url().toString();
+        cDebug() << "  ..Headers: " <<  reply->rawHeaderList();
+        ui->netinst_status->setText( tr( "Network Installation. (Disabled: Received invalid groups data)" ) );
         reply->deleteLater();
+        emit checkReady( !m_required );
         return;
     }
 
@@ -111,15 +112,23 @@ NetInstallPage::dataIsHere( QNetworkReply* reply )
     ui->groupswidget->header()->setSectionResizeMode( 1, QHeaderView::Stretch );
 
     reply->deleteLater();
-    emit checkReady( isReady() );
+    emit checkReady( true );
 }
 
-QList<PackageTreeItem::ItemData> NetInstallPage::selectedPackages() const
+PackageModel::PackageItemDataList
+NetInstallPage::selectedPackages() const
 {
-    return m_groups->getPackages();
+    if ( m_groups )
+        return m_groups->getPackages();
+    else
+    {
+        cWarning() << "no netinstall groups are available.";
+        return PackageModel::PackageItemDataList();
+    }
 }
 
-void NetInstallPage::loadGroupList()
+void
+NetInstallPage::loadGroupList()
 {
     QString confUrl(
         Calamares::JobQueue::instance()->globalStorage()->value(
@@ -138,7 +147,15 @@ void NetInstallPage::loadGroupList()
     m_networkManager.get( request );
 }
 
-void NetInstallPage::onActivate()
+void
+NetInstallPage::setRequired( bool b )
+{
+    m_required = b;
+}
+
+
+void
+NetInstallPage::onActivate()
 {
     ui->groupswidget->setFocus();
 }
