@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
@@ -164,7 +164,18 @@ PartitionCoreModule::doInit()
     for ( auto deviceInfo : m_deviceInfos )
         deviceInfo->partitionModel->init( deviceInfo->device.data(), m_osproberLines );
 
-    m_bootLoaderModel->init( devices );
+    DeviceList bootLoaderDevices;
+
+    for ( DeviceList::Iterator it = devices.begin(); it != devices.end(); ++it)
+        if ( (*it)->type() != Device::Type::Disk_Device )
+        {
+            cDebug() << "Ignoring device that is not Disk_Device to bootLoaderDevices list.";
+            continue;
+        }
+        else
+            bootLoaderDevices.append(*it);
+
+    m_bootLoaderModel->init( bootLoaderDevices );
 
     //FIXME: this should be removed in favor of
     //       proper KPM support for EFI
@@ -247,6 +258,7 @@ PartitionCoreModule::createPartition( Device* device,
     {
         SetPartFlagsJob* fJob = new SetPartFlagsJob( device, partition, flags );
         deviceInfo->jobs << Calamares::job_ptr( fJob );
+        PartitionInfo::setFlags( partition, flags );
     }
 
     refresh();
@@ -370,8 +382,8 @@ PartitionCoreModule::setPartitionFlags( Device* device,
     PartitionModel::ResetHelper( partitionModelForDevice( device ) );
 
     SetPartFlagsJob* job = new SetPartFlagsJob( device, partition, flags );
-
     deviceInfo->jobs << Calamares::job_ptr( job );
+    PartitionInfo::setFlags( partition, flags );
 
     refresh();
 }
@@ -504,19 +516,10 @@ PartitionCoreModule::scanForEfiSystemPartitions()
     }
 
     QList< Partition* > efiSystemPartitions =
-        KPMHelpers::findPartitions( devices,
-                                    []( Partition* partition ) -> bool
-    {
-        if ( partition->activeFlags().testFlag( PartitionTable::FlagEsp ) )
-        {
-            cDebug() << "Found EFI system partition at" << partition->partitionPath();
-            return true;
-        }
-        return false;
-    } );
+        KPMHelpers::findPartitions( devices, PartUtils::isEfiBootable );
 
     if ( efiSystemPartitions.isEmpty() )
-        cDebug() << "WARNING: system is EFI but no EFI system partitions found.";
+        cWarning() << "system is EFI but no EFI system partitions found.";
 
     m_efiSystemPartitions = efiSystemPartitions;
 }
