@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *
@@ -115,7 +115,7 @@ PartitionModel::parent( const QModelIndex& child ) const
             return createIndex( row, 0, parentNode );
         ++row;
     }
-    cLog() << "No parent found!";
+    cWarning() << "No parent found!";
     return QModelIndex();
 }
 
