@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2014-2017, Teo Mrnjavac <teo@kde.org>
@@ -408,7 +408,7 @@ PartitionViewStep::onLeave()
                               .arg( *Calamares::Branding::ShortProductName )
                               .arg( espMountPoint );
             }
-            else if ( esp && !esp->activeFlags().testFlag( PartitionTable::FlagEsp ) )
+            else if ( esp && !PartUtils::isEfiBootable( esp ) )
             {
                 message = tr( "EFI system partition flag not set" );
                 description = tr( "An EFI system partition is necessary to start %1."
@@ -426,6 +426,7 @@ PartitionViewStep::onLeave()
 
             if ( !message.isEmpty() )
             {
+                cWarning() << message;
                 QMessageBox::warning( m_manualPartitionPage,
                                       message,
                                       description );
@@ -535,7 +536,7 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
         gs->insert( "defaultFileSystemType", typeString );
         if ( FileSystem::typeForName( typeString ) == FileSystem::Unknown )
         {
-            cDebug() << "WARNING: bad default filesystem configuration for partition module. Reverting to ext4 as default.";
+            cWarning() << "bad default filesystem configuration for partition module. Reverting to ext4 as default.";
             gs->insert( "defaultFileSystemType", "ext4" );
         }
     }
