@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2017, Adriaan de Groot <groot@kde.org>
  *
@@ -21,6 +21,7 @@
 #include "PlasmaLnfPage.h"
 #include "ThemeInfo.h"
 
+#include "utils/CalamaresUtils.h"
 #include "utils/Logger.h"
 
 #include <QProcess>
@@ -120,10 +121,10 @@ void PlasmaLnfViewStep::onLeave()
 }
 
 
-QList<Calamares::job_ptr>
+Calamares::JobList
 PlasmaLnfViewStep::jobs() const
 {
-    QList<Calamares::job_ptr> l;
+    Calamares::JobList l;
 
     cDebug() << "Creating Plasma LNF jobs ..";
     if ( !m_themeId.isEmpty() )
@@ -131,7 +132,7 @@ PlasmaLnfViewStep::jobs() const
         if ( !m_lnfPath.isEmpty() )
             l.append( Calamares::job_ptr( new PlasmaLnfJob( m_lnfPath, m_themeId ) ) );
         else
-            cDebug() << "WARNING: no lnftool given for plasmalnf module.";
+            cWarning() << "no lnftool given for plasmalnf module.";
     }
     return l;
 }
@@ -140,31 +141,21 @@ PlasmaLnfViewStep::jobs() const
 void
 PlasmaLnfViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    QString lnfPath;
-    if ( configurationMap.contains( "lnftool" ) && configurationMap.value( "lnftool" ).type() == QVariant::String )
-        lnfPath = configurationMap.value( "lnftool" ).toString();
-    m_lnfPath = lnfPath;
+    m_lnfPath = CalamaresUtils::getString( configurationMap, "lnftool" );
     m_widget->setLnfPath( m_lnfPath );
 
     if ( m_lnfPath.isEmpty() )
-        cDebug() << "WARNING: no lnftool given for plasmalnf module.";
+        cWarning() << "no lnftool given for plasmalnf module.";
 
-    QString liveUser;
-    if ( configurationMap.contains( "liveuser" ) && configurationMap.value( "liveuser" ).type() == QVariant::String )
-        liveUser = configurationMap.value( "liveuser" ).toString();
-    m_liveUser = liveUser;
+    m_liveUser = CalamaresUtils::getString( configurationMap, "liveuser" );
 
-    QString preselect;
-    if ( configurationMap.contains( "preselect" ) && configurationMap.value( "preselect" ).type() == QVariant::String )
-        preselect = configurationMap.value( "preselect" ).toString();
+    QString preselect = CalamaresUtils::getString( configurationMap, "preselect" );
     if ( preselect == QStringLiteral( "*" ) )
         preselect = currentPlasmaTheme();
     if ( !preselect.isEmpty() )
         m_widget->setPreselect( preselect );
 
-    bool showAll( false );
-    if ( configurationMap.contains( "showAll" ) && configurationMap.value( "showAll" ).type() == QVariant::Bool )
-        showAll = configurationMap.value( "showAll" ).toBool();
+    bool showAll = CalamaresUtils::getBool( configurationMap, "showAll", false );
 
     if ( configurationMap.contains( "themes" ) &&
         configurationMap.value( "themes" ).type() == QVariant::List )
@@ -184,7 +175,7 @@ PlasmaLnfViewStep::setConfigurationMap( const QVariantMap& configurationMap )
                 listedThemes.append( ThemeInfo( i.toString() ) );
 
         if ( listedThemes.length() == 1 )
-            cDebug() << "WARNING: only one theme enabled in plasmalnf";
+            cWarning() << "only one theme enabled in plasmalnf";
         m_widget->setEnabledThemes( listedThemes, showAll );
     }
     else
@@ -197,7 +188,7 @@ PlasmaLnfViewStep::themeSelected( const QString& id )
     m_themeId = id;
     if ( m_lnfPath.isEmpty() )
     {
-        cDebug() << "WARNING: no lnftool given for plasmalnf module.";
+        cWarning() << "no lnftool given for plasmalnf module.";
         return;
     }
 
@@ -209,17 +200,17 @@ PlasmaLnfViewStep::themeSelected( const QString& id )
 
     if ( !lnftool.waitForStarted( 1000 ) )
     {
-        cDebug() << "WARNING: could not start look-and-feel" << m_lnfPath;
+        cWarning() << "could not start look-and-feel" << m_lnfPath;
         return;
     }
     if ( !lnftool.waitForFinished() )
     {
-        cDebug() << "WARNING:" << m_lnfPath << "timed out.";
+        cWarning() << m_lnfPath << "timed out.";
         return;
     }
 
     if ( ( lnftool.exitCode() == 0 ) && ( lnftool.exitStatus() == QProcess::NormalExit ) )
         cDebug() << "Plasma look-and-feel applied" << id;
     else
-        cDebug() << "WARNING: could not apply look-and-feel" << id;
+        cWarning() << "could not apply look-and-feel" << id;
 }
