@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2017, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017, Adriaan de Groot <groot@kde.org>
@@ -130,6 +130,8 @@ UsersPage::createJobs( const QStringList& defaultGroupsList )
     if ( !isReady() )
         return list;
 
+    Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
+
     Calamares::Job* j;
     j = new CreateUserJob( ui->textBoxUsername->text(),
                            ui->textBoxFullName->text().isEmpty() ?
@@ -145,6 +147,7 @@ UsersPage::createJobs( const QStringList& defaultGroupsList )
 
     if ( m_writeRootPassword )
     {
+        gs->insert( "reuseRootPassword", ui->checkBoxReusePassword->isChecked() );
         if ( ui->checkBoxReusePassword->isChecked() )
             j = new SetPasswordJob( "root",
                                     ui->textBoxUserPassword->text() );
@@ -163,7 +166,6 @@ UsersPage::createJobs( const QStringList& defaultGroupsList )
     j = new SetHostNameJob( ui->textBoxHostname->text() );
     list.append( Calamares::job_ptr( j ) );
 
-    Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
     gs->insert( "hostname", ui->textBoxHostname->text() );
     if ( ui->checkBoxAutoLogin->isChecked() )
         gs->insert( "autologinUser", ui->textBoxUsername->text() );
@@ -455,68 +457,23 @@ UsersPage::setReusePasswordDefault( bool checked )
     emit checkReady( isReady() );
 }
 
-UsersPage::PasswordCheck::PasswordCheck()
-    : m_message()
-    , m_accept( []( const QString& s )
-{
-    return true;
-} )
-{
-}
-
-UsersPage::PasswordCheck::PasswordCheck( const QString& m, AcceptFunc a )
-    : m_message( [m](){ return m; } )
-    , m_accept( a )
-{
-}
-
-UsersPage::PasswordCheck::PasswordCheck( MessageFunc m, AcceptFunc a )
-    : m_message( m )
-    , m_accept( a )
-{
-}
-
 void
 UsersPage::addPasswordCheck( const QString& key, const QVariant& value )
 {
     if ( key == "minLength" )
     {
-        int minLength = -1;
-        if ( value.canConvert( QVariant::Int ) )
-            minLength = value.toInt();
-        if ( minLength > 0 )
-        {
-            cDebug() << key << " .. set to" << minLength;
-            m_passwordChecks.push_back(
-                PasswordCheck(
-                    []()
-            {
-                return tr( "Password is too short" );
-            },
-            [minLength]( const QString& s )
-            {
-                return s.length() >= minLength;
-            } ) );
-        }
+        add_check_minLength( m_passwordChecks, value );
     }
     else if ( key == "maxLength" )
     {
-        int maxLength = -1;
-        if ( value.canConvert( QVariant::Int ) )
-            maxLength = value.toInt();
-        if ( maxLength > 0 )
-        {
-            cDebug() << key << " .. set to" << maxLength;
-            m_passwordChecks.push_back(
-                PasswordCheck( []()
-            {
-                return tr( "Password is too long" );
-            }, [maxLength]( const QString& s )
-            {
-                return s.length() <= maxLength;
-            } ) );
-        }
+        add_check_maxLength( m_passwordChecks, value );
     }
+#ifdef CHECK_PWQUALITY
+    else if ( key == "libpwquality" )
+    {
+        add_check_libpwquality( m_passwordChecks, value );
+    }
+#endif
     else
-        cDebug() << "WARNING: Unknown password-check key" << '"' << key << '"';
+        cWarning() << "Unknown password-check key" << key;
 }
