@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *
@@ -130,7 +130,7 @@ WelcomeViewStep::setConfigurationMap( const QVariantMap& configurationMap )
          configurationMap.value( "requirements" ).type() == QVariant::Map )
         m_requirementsChecker->setConfigurationMap( configurationMap.value( "requirements" ).toMap() );
     else
-        cDebug() << "WARNING: no valid requirements map found in welcome "
+        cWarning() << "no valid requirements map found in welcome "
                     "module configuration.";
 }
 
